{% extends "base.html" %}
{% load staticfiles %}
{% load filters_deploys %}

{% block extra_css %}
<style>
.highlight .hll { background-color: #ffffcc }
.highlight  { background: #f8f8f8; }
.highlight .c { color: #408080; font-style: italic } /* Comment */
.highlight .err { border: 1px solid #FF0000 } /* Error */
.highlight .k { color: #008000; font-weight: bold } /* Keyword */
.highlight .o { color: #666666 } /* Operator */
.highlight .ch { color: #408080; font-style: italic } /* Comment.Hashbang */
.highlight .cm { color: #408080; font-style: italic } /* Comment.Multiline */
.highlight .cp { color: #BC7A00 } /* Comment.Preproc */
.highlight .cpf { color: #408080; font-style: italic } /* Comment.PreprocFile */
.highlight .c1 { color: #408080; font-style: italic } /* Comment.Single */
.highlight .cs { color: #408080; font-style: italic } /* Comment.Special */
.highlight .gd { color: #A00000 } /* Generic.Deleted */
.highlight .ge { font-style: italic } /* Generic.Emph */
.highlight .gr { color: #FF0000 } /* Generic.Error */
.highlight .gh { color: #000080; font-weight: bold } /* Generic.Heading */
.highlight .gi { color: #00A000 } /* Generic.Inserted */
.highlight .go { color: #888888 } /* Generic.Output */
.highlight .gp { color: #000080; font-weight: bold } /* Generic.Prompt */
.highlight .gs { font-weight: bold } /* Generic.Strong */
.highlight .gu { color: #800080; font-weight: bold } /* Generic.Subheading */
.highlight .gt { color: #0044DD } /* Generic.Traceback */
.highlight .kc { color: #008000; font-weight: bold } /* Keyword.Constant */
.highlight .kd { color: #008000; font-weight: bold } /* Keyword.Declaration */
.highlight .kn { color: #008000; font-weight: bold } /* Keyword.Namespace */
.highlight .kp { color: #008000 } /* Keyword.Pseudo */
.highlight .kr { color: #008000; font-weight: bold } /* Keyword.Reserved */
.highlight .kt { color: #B00040 } /* Keyword.Type */
.highlight .m { color: #666666 } /* Literal.Number */
.highlight .s { color: #BA2121 } /* Literal.String */
.highlight .na { color: #7D9029 } /* Name.Attribute */
.highlight .nb { color: #008000 } /* Name.Builtin */
.highlight .nc { color: #0000FF; font-weight: bold } /* Name.Class */
.highlight .no { color: #880000 } /* Name.Constant */
.highlight .nd { color: #AA22FF } /* Name.Decorator */
.highlight .ni { color: #999999; font-weight: bold } /* Name.Entity */
.highlight .ne { color: #D2413A; font-weight: bold } /* Name.Exception */
.highlight .nf { color: #0000FF } /* Name.Function */
.highlight .nl { color: #A0A000 } /* Name.Label */
.highlight .nn { color: #0000FF; font-weight: bold } /* Name.Namespace */
.highlight .nt { color: #008000; font-weight: bold } /* Name.Tag */
.highlight .nv { color: #19177C } /* Name.Variable */
.highlight .ow { color: #AA22FF; font-weight: bold } /* Operator.Word */
.highlight .w { color: #bbbbbb } /* Text.Whitespace */
.highlight .mb { color: #666666 } /* Literal.Number.Bin */
.highlight .mf { color: #666666 } /* Literal.Number.Float */
.highlight .mh { color: #666666 } /* Literal.Number.Hex */
.highlight .mi { color: #666666 } /* Literal.Number.Integer */
.highlight .mo { color: #666666 } /* Literal.Number.Oct */
.highlight .sb { color: #BA2121 } /* Literal.String.Backtick */
.highlight .sc { color: #BA2121 } /* Literal.String.Char */
.highlight .sd { color: #BA2121; font-style: italic } /* Literal.String.Doc */
.highlight .s2 { color: #BA2121 } /* Literal.String.Double */
.highlight .se { color: #BB6622; font-weight: bold } /* Literal.String.Escape */
.highlight .sh { color: #BA2121 } /* Literal.String.Heredoc */
.highlight .si { color: #BB6688; font-weight: bold } /* Literal.String.Interpol */
.highlight .sx { color: #008000 } /* Literal.String.Other */
.highlight .sr { color: #BB6688 } /* Literal.String.Regex */
.highlight .s1 { color: #BA2121 } /* Literal.String.Single */
.highlight .ss { color: #19177C } /* Literal.String.Symbol */
.highlight .bp { color: #008000 } /* Name.Builtin.Pseudo */
.highlight .vc { color: #19177C } /* Name.Variable.Class */
.highlight .vg { color: #19177C } /* Name.Variable.Global */
.highlight .vi { color: #19177C } /* Name.Variable.Instance */
.highlight .il { color: #666666 } /* Literal.Number.Integer.Long */

span.status-success {
  color: #527c2b;
}

span.status-running {
  color: #333;
}

span.status-canceled {
  color: #999;
}

span.status-error {
  color: #bc2e1b;
}

#modal {
  text-align: center;
  padding: 0!important;
}

#modal:before {
  content: '';
  display: inline-block;
  height: 100%;
  vertical-align: middle;
  margin-right: -4px;
}
</style>
{% endblock %}

{% block bar %}
<div class="bar">
  <a href="/">dashboard</a> <span class="arrow">></span>
  <a href="{% url 'event-list' %}">events</a> <span class="arrow">></span>
  {{ event.Kind.Name }} / {{ event.Target.Value }}

  {% if event.Cancelable and event.Running %}
  <button id="cancel-button">Cancel</button>
  {% endif %}
</div>
{% endblock %}

{% block header %}
<h1>Events</h1>
{% endblock %}

{% block content %}
<div id="modal"></div>
<div class="container-fluid">
  <div class="row">
    <div class="col-md-12">
      <div class="content">
        <p>
          Status:
          <span class="{% if not event.Running and not event.CancelInfo.Canceled and not event.Error %}status-success{% endif %}{% if event.Running %}status-running{% endif %}{% if event.Error %}status-error{% endif %}">
            {% if event.Running %}
            Running
            {% endif %}
            {% if event.Error %}
            Error
            {% endif %}
            {% if not event.Running and not event.CancelInfo.Canceled and not event.Error %}
            Success
            {% endif %}
          </span>
        </p>
        {% if event.Error %}
        <p><strong>Error message:</strong> {{ event.Error }}</p>
        {% endif %}
        {% if event.CancelInfo.Canceled %}
        <p><strong>Event canceled by:</strong> {{ event.CancelInfo.Owner }}</p>
        <p><strong>Reason:</strong> {{ event.CancelInfo.Reason }}</p>
        {% endif %}
        <p><strong>unique id:</strong> {{ event.UniqueID }}</p>
        <p><strong>kind:</strong> {{ event.Kind.Name }}</p>
        <p><strong>{{ event.Owner.Type }}:</strong> {{ event.Owner.Name }}</p>
        <p><strong>{{ event.Target.Type }}:</strong> {{ event.Target.Value }}</p>
        {% if event.StartTime %}
        <p><strong>started at:</strong> {{ event.StartTime|string_to_date|date:" d-m-Y H:i:s " }}</p>
        {% endif %}
        {% if event.EndTime %}
        <p><strong>finished at:</strong> {{ event.EndTime|string_to_date|date:" d-m-Y H:i:s " }}</p>
        {% endif %}
        {% if event.StartCustomData.Kind %}
        <p><strong>Start Custom Data: </strong></p>
        {{ event.StartCustomData.Data | safe }}
        {% endif %}
        {% if event.EndCustomData.Kind %}
        <p><strong>End Custom Data: </strong></p>
        {{ event.EndCustomData.Data | safe }}
        {% endif %}
        {% if event.OtherCustomData.Kind %}
        <p><strong>Other Custom Data: </strong></p>
        {{ event.OtherCustomData.Data | safe }}
        {% endif %}
        {% if event.Log %}
        <p><strong>Log:</strong></p>
        <div><pre>{{ event.Log | escape }}</pre></div>
        {% endif %}
      </div>
    </div>
  </div>
</div>
{% endblock %}

{% block extra_js %}
<script src="{% static "js/event-info.js" %}"></script>
{% endblock %}
